<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
	<xsl:output method="xml"/>
	<xsl:template name="VagonRwFlk">
		<xsl:param name="NumVagon"/>
		<xsl:param name="RwbType"/>
		<xsl:param name="RwbPos"/>
		<xsl:param name="NodeRw"/> 
		<xsl:param name="Pos"/>
		<xsl:param name="Flg"/>	
		<xsl:if test="string-length(GoodsWeight)=0 and number(../../GrossWeightQuantity)>0">
			<xsl:call-template name="ErrorNode">
				<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с вагоном, у которого не заполнено поле Вес груза в вагоне .'"/>
				<xsl:with-param name="DocId" select="../../../@id"/>
				<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/',$NodeRw,'[',$Pos,']/GoodsWeight')"/>
				<xsl:with-param name="TypeDoc" select="$RwbType"/>
				<xsl:with-param name="PosPkg" select="$RwbPos"/>						
			</xsl:call-template>						
		</xsl:if>
		<xsl:if test="string-length(OwnerType)>0 and (OwnerType='P' or OwnerType='A') and string-length(OwnerName)=0">
			<xsl:call-template name="ErrorNode">
				<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с вагоном, у которого указан Тип собственника (P - не принадлежит/A-аренда ) и не заполнено поле Собственник вагона .'"/>
				<xsl:with-param name="DocId" select="../../../@id"/>
				<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/',$NodeRw,'[',$Pos,']/OwnerName')"/>
				<xsl:with-param name="TypeDoc" select="$RwbType"/>
				<xsl:with-param name="PosPkg" select="$RwbPos"/>						
			</xsl:call-template>						
		</xsl:if>
		<xsl:if test="string-length(OwnerType)>0 and OwnerType='A' and string-length(TenantName)=0">
			<xsl:call-template name="ErrorNode">
				<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с вагоном, у которого указан Тип собственника (A-аренда )  и не заполнено поле Арендатор вагона .'"/>
				<xsl:with-param name="DocId" select="../../../@id"/>
				<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/',$NodeRw,'[',$Pos,']/TenantName')"/>
				<xsl:with-param name="TypeDoc" select="$RwbType"/>
				<xsl:with-param name="PosPkg" select="$RwbPos"/>						
			</xsl:call-template>						
		</xsl:if>
		<xsl:choose>
			<xsl:when test="$Flg=0">
				<xsl:if test="string-length($NumVagon)=7 and string-length(CarriageLand)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с вагоном, у которого не заполнено поле Код страны собственника.'"/>
						<xsl:with-param name="DocId" select="../../../@id"/>
						<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/',$NodeRw,'[',$Pos,']/CarriageLand')"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
			</xsl:when>
			<xsl:when test="$Flg=1">
				<xsl:if test="string-length($NumVagon)=7 and string-length(WOWNER)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с вагоном в вагонной ведомости, у которого не заполнено поле Код страны собственника.'"/>
						<xsl:with-param name="DocId" select="../../../@id"/>
						<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/',$NodeRw,'[',$Pos,']/WOWNER')"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
			</xsl:when>
		</xsl:choose>

	</xsl:template>	
	<xsl:template name="ErrorNode">
		<xsl:param name="MessErr"/>
		<xsl:param name="DocId"/>
		<xsl:param name="PathErr"/>
		<xsl:param name="Category"/>
		<xsl:param name="Num"/>
		<xsl:param name="TypeDoc"/>
		<xsl:param name="PosPkg"/>
		<xsl:variable name="Cat">
			<xsl:choose>
				<xsl:when test="string-length($Category)=0">ERROR</xsl:when>
				<xsl:otherwise><xsl:value-of select="$Category" /></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<RESULTINFORMATION_ITEM  xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<ResultDescription><xsl:value-of select="$MessErr"/></ResultDescription>
			<ResultIdDocument><xsl:value-of select="$DocId"/></ResultIdDocument>
			<ResultTypeDocument><xsl:value-of select="$TypeDoc"/></ResultTypeDocument>
			<ResultPosInPkgDocument><xsl:value-of select="$PosPkg"/></ResultPosInPkgDocument>
			<ResultPathNode><xsl:value-of select="$PathErr"/></ResultPathNode>
			<ResultCategory><xsl:value-of select="$Cat"/></ResultCategory>
			<DocumentNumber><xsl:value-of select="$Num"/></DocumentNumber>
		</RESULTINFORMATION_ITEM>	
	</xsl:template>
	
	<xsl:template match="/">
		<xsl:apply-templates select="//Package"/>
	</xsl:template>
		<!-- проверка связанности док-тов в пакете-->
		
	<xsl:template match="Package">
		<ResultInformation   xmlns:ctmtd="http://rail.ctm.ru/TD/Document">
			<xsl:if test="count(//INVOICE/INVOICE_ITEM)>0 and count(//RWB/RWB_ITEM)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет не содержит ни одной накладной.'"/>
					</xsl:call-template>		
			</xsl:if>
			<xsl:for-each select="//INVOICE/INVOICE_ITEM">
				<xsl:variable name="IdInv" select="../@id"/>
				<xsl:variable name="InvType" select="../@ctmtd:CfgName"/>
				<xsl:variable name="InvPos" select="position()"/>
				<xsl:if test="string-length(RegNum)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс без номера регистрации документа.'"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/RegNum'"/>					
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(RegNum)>30">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с номером регистрации документа, длина которого больше 30 символов.'"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/RegNum'"/>					
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(RegDate)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс без даты регистрации документа.'"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/RegDate'"/>								
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
					</xsl:call-template>	
				</xsl:if>
				<xsl:if test="string-length(CurrencyCode)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с незаполненным кодом валюты.'"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/CurrencyCode'"/>					
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
					</xsl:call-template>
				</xsl:if>	
				<xsl:if test="string-length(DispatchCountryCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем  Код страны отправления '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/DispatchCountryCode'"/>								
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
					</xsl:call-template>	
				</xsl:if>
				<xsl:if test="string-length(DestinationCountryCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Код страны назначения '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/DestinationCountryCode'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Seler_Name)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Продавец: Наименование  '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Seler_Name'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Seler_CountryCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Продавец: Код страны  '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Seler_CountryCode'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:variable name="SelCr" select="Seler_CountryCode"/>
				<xsl:if test="string-length(Seler_CountryCode)>0  and string-length(document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$SelCr]/Code)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с неправильно заполненным полем Продавец: Код страны - отсутствует в справочнике '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Seler_CountryCode'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				
				<xsl:if test="string-length(Seler_City)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Продавец: Город  '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Seler_City'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Seler_StreetHouse)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Продавец:Улица, номер дома, номер офиса.  '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Seler_StreetHouse'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Seler_PostalCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Продавец:Индекс'"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Seler_PostalCode'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Buyer_Name)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Покупатель: Наименование  '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Buyer_Name'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Buyer_CountryCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Покупатель: Код страны  '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Buyer_CountryCode'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:variable name="BayCr" select="Buyer_CountryCode"/>
				<xsl:if test="string-length(Buyer_CountryCode)>0  and string-length(document('../../NSI/TranspNSIXml.xml')//Country_ITEM[ABC2=$BayCr]/Code)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с неправильно заполненным полем Покупатель: Код страны - отсутствует в справочнике '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Buyer_CountryCode'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Buyer_City)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Покупатель: Город  '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Buyer_City'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Buyer_StreetHouse)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Покупатель:Улица, номер дома, номер офиса.  '"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Buyer_StreetHouse'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Buyer_PostalCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с не заполненным полем Покупатель:Индекс'"/>
						<xsl:with-param name="DocId" select="$IdInv"/>
						<xsl:with-param name="PathErr" select="'INVOICE/INVOICE_ITEM/Buyer_PostalCode'"/>			
						<xsl:with-param name="TypeDoc" select="$InvType"/>
						<xsl:with-param name="PosPkg" select="$InvPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>		
					</xsl:call-template>
				</xsl:if>
				<xsl:for-each select="INVOICEGoods/INVOICEGOODS_ITEM">
					<xsl:variable name="PosGoods" select="position()"/>
					<xsl:if test="string-length(GoodsDescription)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с товаром, в котором не заполнено поле Наименование товара. '"/>
							<xsl:with-param name="DocId" select="$IdInv"/>
							<xsl:with-param name="PathErr" select="concat('INVOICE/INVOICE_ITEM/INVOICEGoods/INVOICEGOODS_ITEM[',$PosGoods,']/GoodsDescription')"/>
							<xsl:with-param name="TypeDoc" select="$InvType"/>
							<xsl:with-param name="PosPkg" select="$InvPos"/>
						</xsl:call-template>								
					</xsl:if>  
					<xsl:if test="string-length(GoodsCode)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с товаром, в котором не заполнено поле Код ТН ВЭД. '"/>
							<xsl:with-param name="DocId" select="$IdInv"/>
							<xsl:with-param name="PathErr" select="concat('INVOICE/INVOICE_ITEM/INVOICEGoods/INVOICEGOODS_ITEM[',$PosGoods,']/GoodsCode')"/>
							<xsl:with-param name="TypeDoc" select="$InvType"/>
							<xsl:with-param name="PosPkg" select="$InvPos"/>
						</xsl:call-template>								
					</xsl:if>  					
					<xsl:if test="string-length(PlacesCode)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с товаром, в котором не заполнено поле Код грузового места. '"/>
							<xsl:with-param name="DocId" select="$IdInv"/>
							<xsl:with-param name="PathErr" select="concat('INVOICE/INVOICE_ITEM/INVOICEGoods/INVOICEGOODS_ITEM[',$PosGoods,']/PlacesCode')"/>		
							<xsl:with-param name="TypeDoc" select="$InvType"/>
							<xsl:with-param name="PosPkg" select="$InvPos"/>
						</xsl:call-template>								
					</xsl:if>
					<xsl:variable name="PackN" select="PlacesCode"/>
					<xsl:if test="string-length($PackN)>0 and string-length(document('../../NSI/Ldznsi.xml')//PACKAGE_LDZ_ITEM[CODENSI=$PackN]/CodeLDZ)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с товаром, в котором Код грузового места указан не верно (отсутсвует в справочнике). '"/>
							<xsl:with-param name="DocId" select="$IdInv"/>
							<xsl:with-param name="PathErr" select="concat('INVOICE/INVOICE_ITEM/INVOICEGoods/INVOICEGOODS_ITEM[',$PosGoods,']/PlacesCode')"/>		
							<xsl:with-param name="TypeDoc" select="$InvType"/>
							<xsl:with-param name="PosPkg" select="$InvPos"/>
						</xsl:call-template>								
					</xsl:if>
					<xsl:if test="string-length(GrossWeightQuantity)=0 or  (round(number(GrossWeightQuantity) * 1000) div 1000)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с товаром, в котором не заполнено или равно 0 поле Вес брутто.'"/>
							<xsl:with-param name="DocId" select="$IdInv"/>
							<xsl:with-param name="PathErr" select="concat('INVOICE/INVOICE_ITEM/INVOICEGoods/INVOICEGOODS_ITEM[',$PosGoods,']/GrossWeightQuantity')"/>		
							<xsl:with-param name="TypeDoc" select="$InvType"/>
							<xsl:with-param name="PosPkg" select="$InvPos"/>
						</xsl:call-template>								
					</xsl:if>
					<xsl:if test="string-length(TotalCost)=0 or (round(TotalCost * 100) div 100)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит инвойс с товаром, в котором не заполнено или равно 0 поле Стоимость.'"/>
							<xsl:with-param name="DocId" select="$IdInv"/>
							<xsl:with-param name="PathErr" select="concat('INVOICE/INVOICE_ITEM/INVOICEGoods/INVOICEGOODS_ITEM[',$PosGoods,']/TotalCost')"/>		
							<xsl:with-param name="TypeDoc" select="$InvType"/>
							<xsl:with-param name="PosPkg" select="$InvPos"/>
						</xsl:call-template>								
					</xsl:if>
				</xsl:for-each>
			</xsl:for-each>

			<xsl:for-each select="//RWB/RWB_ITEM">
				<xsl:variable name="RwbPos" select="position()"/>
				<xsl:variable name="RwbType" select="../@ctmtd:CfgName"/>
				<xsl:variable name="IdRw" select="../@id"/>
				<xsl:if test="string-length(RegNum)=0">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС без номера регистрации документа.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/RegNum'"/>	
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>	
				</xsl:if>
				<!--<xsl:for-each select="RWBConsignorDocument/RWBCONSIGNORDOCUMENT_ITEM[string-length(ModeCode)>0]">
					<xsl:variable name="Num" select="DocumentNumber"/>
					<xsl:variable name="Dat" select="substring(DocumentDate,1,10)"/>
					<xsl:variable name="PosRwbDoc" select="position()"/>
					<xsl:if test="ModeCode='04021' and count(//INVOICE/INVOICE_ITEM[RegNum=$Num and substring(RegDate,1,10)=$Dat])=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с инвойсом в 24 графе,который отсутсвует в пакете или  неправильно указаны номер или дата.'"/>
							<xsl:with-param name="DocId" select="$IdRw"/>
							<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBConsignorDocument/RWBCONSIGNORDOCUMENT_ITEM[',$PosRwbDoc,']/DocumentNumber')"/>					
							<xsl:with-param name="TypeDoc" select="$RwbType"/>
							<xsl:with-param name="PosPkg" select="$RwbPos"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:for-each>-->
				<xsl:if test="string-length(Consignor_Name)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Отправитель: Наименование  '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignor_Name'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:variable name="RwCodeCnor">
					<xsl:choose>
						<xsl:when test="string-length(Consignor_RailCode)>0">
							<xsl:value-of select="Consignor_RailCode"/>
						</xsl:when>
						<xsl:when test="string-length(Consignor_OKPOID)>0 and string-length(Consignor_OKPOID)=4">
							<xsl:value-of select="Consignor_OKPOID"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				
				<xsl:if test="string-length($RwCodeCnor)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Отправитель: ЖД код '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr">
							<xsl:choose>
								<xsl:when test="string-length(Consignor_RailCode)=0 and count(Consignor_RailCode)>0">
									<xsl:value-of select="'RWB/RWB_ITEM/Consignor_RailCode'"/>			
								</xsl:when>
								<xsl:when test="count(Consignor_RailCode)=0 and string-length(Consignor_OKPOID)=0">
									<xsl:value-of select="'RWB/RWB_ITEM/Consignor_OKPOID'"/>
								</xsl:when>
							</xsl:choose>
						</xsl:with-param> 
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignor_CountryCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Отправитель: Код страны  '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignor_CountryCode'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignor_City)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Отправитель: Город  '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignor_City'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignor_StreetHouse)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Отправитель:Улица, номер дома, номер офиса.  '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignor_StreetHouse'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignor_PostalCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Отправитель:Индекс'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignor_PostalCode'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignee_Name)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Получатель: Наименование  '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignee_Name'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:variable name="RwCodeCnee">
					<xsl:choose>
						<xsl:when test="string-length(Consignee_RailCode)>0">
							<xsl:value-of select="Consignee_RailCode"/>
						</xsl:when>
						<xsl:when test="string-length(Consignee_OKPOID)>0 and string-length(Consignee_OKPOID)=4">
							<xsl:value-of select="Consignee_OKPOID"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<xsl:if test="string-length($RwCodeCnee)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Получатель: ЖД код '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr">
							<xsl:choose>
								<xsl:when test="string-length(Consignee_RailCode)=0 and count(Consignee_RailCode)>0">
									<xsl:value-of select="'RWB/RWB_ITEM/Consignee_RailCode'"/>			
								</xsl:when>
								<xsl:when test="count(Consignee_RailCode)=0 and string-length(Consignee_OKPOID)=0">
									<xsl:value-of select="'RWB/RWB_ITEM/Consignee_OKPOID'"/>
								</xsl:when>
							</xsl:choose>
						</xsl:with-param> 
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignee_CountryCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Получатель: Код страны  '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignee_CountryCode'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignee_City)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Получатель: Город  '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignee_City'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignee_StreetHouse)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Получатель:Улица, номер дома, номер офиса.  '"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignee_StreetHouse'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignee_PostalCode)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненным полем Получатель:Индекс'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignee_PostalCode'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(Consignee_CountryCode)>0 and string-length(Consignor_CountryCode)>0 and Consignee_CountryCode=Consignor_CountryCode">
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Значения полей СМГС Грузополучатель Код cтраны и Грузоотправитель Код cтраны совпадают.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/Consignor_CountryCode'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
						<xsl:with-param name="Category" select="'WARNING'"/>
					</xsl:call-template>	
				</xsl:if>
				<xsl:if test="string-length(WeightDefinitionModeDescription)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с не заполненной 48 гр.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/WeightDefinitionModeDescription'"/>			
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="string-length(GrossWeightQuantity)=0 or number(GrossWeightQuantity)=0">	
					<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненным или равным 0 полем Общий вес товаров, определенный отправителем, брутто (кг).'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/GrossWeightQuantity'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(DepStationCode)=0"> 
					<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненным полем Код станции отправления.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/DepStationCode'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(DestStationCode)=0"> 
					<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненным полем Код станции назначения.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/DestStationCode'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(DepartureStationCode)=0"> 
					<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненным полем Код станции открытия таможенного транзита по РФ (ВТТ).'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/DepartureStationCode'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="StatIn" select="DepartureStationCode"/>
				<xsl:variable name="CodeTO">
					<xsl:choose>
						<xsl:when test="string-length(DepartureCustomCode)>0"><xsl:value-of select="DepartureCustomCode"/></xsl:when>
						<xsl:otherwise>
							<xsl:value-of  select="document('../../NSI/TranspNSIXml.xml')//GDStanANDCust_ITEM[CODESTAN=substring($StatIn,1,5) and string-length(Code)>0]/Code"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:if test="string-length($CodeTO)=0"> 
					<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Код станции открытия таможенного транзита по РФ (ВТТ), на которой нет таможенного поста.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/DepartureStationCode'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length($CodeTO)>0 and string-length(document('../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$CodeTO]/Code)=0"> 
					<xsl:call-template name="ErrorNode">
						<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Код таможенного поста не найден в справочнике.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/DepartureCustomCode'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(DestinationStationCode)=0"> 
					<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненным полем Код станции закрытия таможенного транзита по РФ (МТТ).'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/DestinationStationCode'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length(ContainerID)>0 and string-length(ContainerWeight)=0"> 
					<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненным полем Вес контейнера.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/ContainerWeight'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:variable name="StatOut" select="DestinationStationCode"/>
				<xsl:variable name="CodeOut">
					<xsl:choose>
						<xsl:when test="string-length(DestinationCustomCode)>0"><xsl:value-of select="DestinationCustomCode"/></xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="document('../../NSI/TranspNSIXml.xml')//GDStanANDCust_ITEM[CODESTAN=$StatOut and string-length(Code)>0]/Code"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:if test="string-length($CodeOut)=0"> 
					<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Код станции закрытия таможенного транзита по РФ (ВТТ), на которой нет таможенного поста.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/DestinationStationCode'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:if test="string-length($CodeOut)>0 and string-length(document('../../NSI/TranspNSIXml.xml')//Customs_ITEM[Code=$CodeOut]/Code)=0"> 
					<xsl:call-template name="ErrorNode">
					<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Код таможенного поста не найден в справочнике.'"/>
						<xsl:with-param name="DocId" select="$IdRw"/>
						<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/DestinationCustomCode'"/>						
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
					</xsl:call-template>						
				</xsl:if>
				<xsl:choose>
					<xsl:when test="count(RWBCarriage/RWBCARRIAGE_ITEM[string-length(CarriageId)>0 and CarriageId!='см.Вагонную ведомость'])=0 and count(SMGS_VAGONS/SMGS_VAGONS_ITEM[string-length(RailwayBill)>0])=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненными графами о вагоне(ах).'"/>
							<xsl:with-param name="DocId" select="$IdRw"/>
							<xsl:with-param name="PathErr" select="'RWB/RWBCarriage/RWBCARRIAGE_ITEM[1]/CarriageId'"/>	
						<xsl:with-param name="TypeDoc" select="$RwbType"/>
						<xsl:with-param name="PosPkg" select="$RwbPos"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="count(RWBCarriage/RWBCARRIAGE_ITEM[string-length(CarriageId)>0 and CarriageId!='см.Вагонную ведомость'])>0">
								<xsl:for-each select="RWBCarriage/RWBCARRIAGE_ITEM[string-length(CarriageId)>0 and CarriageId!='см.Вагонную ведомость']">
									<xsl:call-template name="VagonRwFlk">
										<xsl:with-param name="NumVagon" select="CarriageId"/>
										<xsl:with-param name="RwbType" select="$RwbType"/>
										<xsl:with-param name="RwbPos" select="$RwbPos"/>
										<xsl:with-param name="NodeRw" select="'RWBCarriage/RWBCARRIAGE_ITEM'"/>
										<xsl:with-param name="Pos" select="position()"/>
										<xsl:with-param name="Flg" select="0"/>
									</xsl:call-template>	
								</xsl:for-each>	
							</xsl:when>
							<xsl:when test="count(SMGS_VAGONS/SMGS_VAGONS_ITEM[string-length(RailwayBill)>0])>0">
								<xsl:for-each select="SMGS_VAGONS/SMGS_VAGONS_ITEM[string-length(RailwayBill)>0]">
									<xsl:call-template name="VagonRwFlk">
										<xsl:with-param name="NumVagon" select="RailwayBill"/>
										<xsl:with-param name="RwbType" select="$RwbType"/>
										<xsl:with-param name="RwbPos" select="$RwbPos"/>
										<xsl:with-param name="NodeRw" select="'SMGS_VAGONS/SMGS_VAGONS_ITEM'"/>
										<xsl:with-param name="Pos" select="position()"/>
										<xsl:with-param name="Flg" select="1"/>										
									</xsl:call-template>
								</xsl:for-each>	
							</xsl:when>
						</xsl:choose>
					</xsl:otherwise>		
				</xsl:choose>
				<xsl:for-each select="RWBSeal/RWBSEAL_ITEM">
					<xsl:if test="string-length(SealId)=0 and string-length(SealQuantity)>0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС, в котором гр. 19 Пломбы не заполнена гр  Номер пломбы.'"/>
							<xsl:with-param name="DocId" select="$IdRw"/>
							<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBSeal/RWBSEAL_ITEM[',position(),']/SealId')"/>						
							<xsl:with-param name="TypeDoc" select="$RwbType"/>
							<xsl:with-param name="PosPkg" select="$RwbPos"/>
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(SealId)>0 and string-length(SealQuantity)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС, в котором гр. 19 Пломбы не заполнена гр  Кол-во.'"/>
							<xsl:with-param name="DocId" select="$IdRw"/>
							<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBSeal/RWBSEAL_ITEM[',position(),']/SealQuantity')"/>						
							<xsl:with-param name="TypeDoc" select="$RwbType"/>
							<xsl:with-param name="PosPkg" select="$RwbPos"/>
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(SealId)>0 and string-length(WhoseSeal)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС, в котором гр. 19 Пломбы не заполнена гр Принадлежность пломбы .'"/>
							<xsl:with-param name="DocId" select="$IdRw"/>
							<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBSeal/RWBSEAL_ITEM[',position(),']/WhoseSeal')"/>						
							<xsl:with-param name="TypeDoc" select="$RwbType"/>
							<xsl:with-param name="PosPkg" select="$RwbPos"/>
							<xsl:with-param name="Category" select="'WARNING'"/>
						</xsl:call-template>						
					</xsl:if>
					<xsl:if test="string-length(SealId)>0 and string-length(TypeSeal)=0"> 
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС, в котором гр. 19 Пломбы не заполнена гр Тип пломбы .'"/>
							<xsl:with-param name="DocId" select="$IdRw"/>
							<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBSeal/RWBSEAL_ITEM[',position(),']/TypeSeal')"/>						
							<xsl:with-param name="TypeDoc" select="$RwbType"/>
							<xsl:with-param name="PosPkg" select="$RwbPos"/>
							<xsl:with-param name="Category" select="'WARNING'"/>
						</xsl:call-template>						
					</xsl:if>
				</xsl:for-each>
				<xsl:choose>
					<xsl:when test="count(RWBGoods_dop11/RWBGOODS_DOP11_ITEM[string-length(GNG)>0 or string-length(GoodsCode)>0])>0">
						<xsl:for-each select="RWBGoods_dop11/RWBGOODS_DOP11_ITEM[string-length(GNG)>0 or string-length(GoodsCode)>0]">
							<xsl:if test="string-length(GNG)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненым полем Код ГНГ в Приложении 11.'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_dop11/RWBGOODS_DOP11_ITEM[',position(),']/GNG')"/>						
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(GNG)>8"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Кодом ГНГ в Приложении 11  с длиной более 8 символов. При отправке в КПС LDZ будет отправлен 8-значный код.'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_dop11/RWBGOODS_DOP11_ITEM[',position(),']/GNG')"/>						
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
									<xsl:with-param name="Category" select="'WARNING'"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(ETSNG)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненым полем Код ETSNG в Приложении 11.'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_dop11/RWBGOODS_DOP11_ITEM[',position(),']/ETSNG')"/>						
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:variable name="Pack11" select="PlacesCode"/>
							<xsl:if test="string-length($Pack11)>0 and string-length(document('../../NSI/Ldznsi.xml')//PACKAGE_LDZ_ITEM[CODENSI=$Pack11]/CodeLDZ)=0">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром в Приложении 11, в котором Код грузового места указан не верно (отсутсвует в справочнике). '"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_dop11/RWBGOODS_DOP11_ITEM[',position(),']/PlacesCode')"/>						
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>								
							</xsl:if>
							<xsl:if test="string-length(GoodsCode)=0">
								<xsl:variable name="CodGNG" select="GNG"/>
								<xsl:variable name="CodGNGUsl" select="count(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,8)=substring($CodGNG,1,8)])"/>
								<xsl:variable name="CodGNGUsl1" select="count(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,6)=substring($CodGNG,1,6)])"/>
								<xsl:variable name="CodGNGUsl2" select="count(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,4)=substring($CodGNG,1,4)])"/>						
								<xsl:variable name="CodGNGUsl3" select="count(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,2)=substring($CodGNG,1,2)])"/>		
								<xsl:if  test="$CodGNGUsl=0 and $CodGNGUsl1=0 and $CodGNGUsl2=0 and $CodGNGUsl3=0">
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Кодом ГНГ в Приложении 11, по которому невозможно определить товар в Инвойсе(ах).'"/>
										<xsl:with-param name="DocId" select="$IdRw"/>
										<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_dop11/RWBGOODS_DOP11_ITEM[',position(),']/GNG')"/>						
										<xsl:with-param name="TypeDoc" select="$RwbType"/>
										<xsl:with-param name="PosPkg" select="$RwbPos"/>
									</xsl:call-template>						
								</xsl:if>
								<xsl:if test="string-length(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,8)=substring($CodGNG,1,8)]/GrossWeightQuantity)=0 and string-length(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,6)=substring($CodGNG,1,6)]/GrossWeightQuantity)=0 and string-length(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,4)=substring($CodGNG,1,4)]/GrossWeightQuantity)=0"> 
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром в Приложении 11, для которого в товаре  Инвойса(ах) не указан вес брутто.'"/>
										<xsl:with-param name="DocId" select="$IdRw"/>
										<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_dop11/RWBGOODS_DOP11_ITEM[',position(),']/GNG')"/>						
										<xsl:with-param name="TypeDoc" select="$RwbType"/>
										<xsl:with-param name="PosPkg" select="$RwbPos"/>
									</xsl:call-template>						
								</xsl:if>
								<xsl:if test="string-length(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,8)=substring($CodGNG,1,8)]/TotalCost)=0 and string-length(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,6)=substring($CodGNG,1,6)]/TotalCost)=0 and string-length(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,4)=substring($CodGNG,1,4)]/TotalCost)=0"> 
									<xsl:call-template name="ErrorNode">
										<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром в Приложении 11, для которого в товаре  Инвойса(ах) не указана стоимость.'"/>
										<xsl:with-param name="DocId" select="$IdRw"/>
										<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_dop11/RWBGOODS_DOP11_ITEM[',position(),']/GNG')"/>						
										<xsl:with-param name="TypeDoc" select="$RwbType"/>
										<xsl:with-param name="PosPkg" select="$RwbPos"/>
									</xsl:call-template>						
								</xsl:if>
							</xsl:if>
							<xsl:variable name="CodGood" select="GoodsCode"/>
							<xsl:variable name="CodWh" select="GrossWeightQuantity"/>
							<xsl:if test="count(//INVOICEGoods/INVOICEGOODS_ITEM[GoodsCode=$CodGood and GrossWeightQuantity=$CodWh])=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром в Приложении 11, для которого не найден товар в инвойсе(ах) (см. код и вес нетто).'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_dop11/RWBGOODS_DOP11_ITEM[',position(),']/GoodsCode')"/>						
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="count(RWBGoods_Auto/RWBGOODS_AUTO_ITEM[string-length(GoodsCode)>0])>0">
						<xsl:for-each select="RWBGoods_Auto/RWBGOODS_AUTO_ITEM[string-length(GoodsCode)>0]">
							<xsl:if test="string-length(GoodsCode)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненым полем Код товара в Авто-Приложении .'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_Auto/RWBGOODS_AUTO_ITEM[',position(),']/GoodsCode')"/>						
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(VINID)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненым полем VIN в Авто-Приложении .'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_Auto/RWBGOODS_AUTO_ITEM[',position(),']/VINID')"/>						
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:variable name="CodGNG" select="GoodsCode"/>
							<xsl:variable name="GoodsVin" select="VINID"/>
							<xsl:if test="count(//INVOICEGoods/INVOICEGOODS_ITEM[GoodsCode=$CodGNG and normalize-space(VINID)=$GoodsVin])=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Кодом товара и VIN в Авто-Приложении, по которому невозможно определить товар в Инвойсе(ах).'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_Auto/RWBGOODS_AUTO_ITEM[',position(),']/GoodsCode')"/>				
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(//INVOICEGoods/INVOICEGOODS_ITEM[GoodsCode=$CodGNG and normalize-space(VINID)=$GoodsVin]/GrossWeightQuantity)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром в Авто-Приложении, для которого в товаре  Инвойса(ах) не указан вес брутто.'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_Auto/RWBGOODS_AUTO_ITEM[',position(),']/GoodsCode')"/>								
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(//INVOICEGoods/INVOICEGOODS_ITEM[GoodsCode=$CodGNG and normalize-space(VINID)=$GoodsVin]/TotalCost)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром в Авто-Приложении, для которого в товаре  Инвойса(ах) не указана стоимость.'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods_Auto/RWBGOODS_AUTO_ITEM[',position(),']/GoodsCode')"/>							
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="string-length(GNG)>0">
						<xsl:if test="string-length(GNG)>8"> 
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Кодом ГНГ длиной более 8 символов. При отправке в КПС LDZ будет отправлен 8-значный код.'"/>
								<xsl:with-param name="DocId" select="$IdRw"/>
								<xsl:with-param name="PathErr" select="RWB/RWB_ITEM/GNG"/>						
								<xsl:with-param name="TypeDoc" select="$RwbType"/>
								<xsl:with-param name="PosPkg" select="$RwbPos"/>
								<xsl:with-param name="Category" select="'WARNING'"/>
							</xsl:call-template>						
						</xsl:if>
						<xsl:if test="string-length(ETSNG)=0"> 
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненым полем Код ETSNG.'"/>
								<xsl:with-param name="DocId" select="$IdRw"/>
								<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/GNG'"/>						
								<xsl:with-param name="TypeDoc" select="$RwbType"/>
								<xsl:with-param name="PosPkg" select="$RwbPos"/>
							</xsl:call-template>						
						</xsl:if>
						<xsl:variable name="CodGNG" select="GNG"/>
						<xsl:variable name="CodGNGUsl" select="count(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,8)=substring($CodGNG,1,8)])"/>
						<xsl:variable name="CodGNGUsl1" select="count(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,6)=substring($CodGNG,1,6)])"/>
						<xsl:variable name="CodGNGUsl2" select="count(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,4)=substring($CodGNG,1,4)])"/>						
						<xsl:variable name="CodGNGUsl3" select="count(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,2)=substring($CodGNG,1,2)])"/>												

						<xsl:if  test="$CodGNGUsl=0 and $CodGNGUsl1=0 and $CodGNGUsl2=0 and $CodGNGUsl3=0">
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Кодом ГНГ, по которому невозможно определить товар в Инвойсе(ах).'"/>
								<xsl:with-param name="DocId" select="$IdRw"/>
								<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/GNG'"/>	
								<xsl:with-param name="TypeDoc" select="$RwbType"/>
								<xsl:with-param name="PosPkg" select="$RwbPos"/>
							</xsl:call-template>						
						</xsl:if>
						<xsl:variable name="GNG">
							<xsl:choose>
								<xsl:when  test="$CodGNGUsl>0">
									<xsl:value-of select="substring($CodGNG,1,8)"/>
								</xsl:when>
								<xsl:when  test="$CodGNGUsl1>0">
									<xsl:value-of select="substring($CodGNG,1,6)"/>
								</xsl:when>
								<xsl:when  test="$CodGNGUsl2>0">
									<xsl:value-of select="substring($CodGNG,1,4)"/>
								</xsl:when>
								<xsl:when  test="count(//INVOICEGoods/INVOICEGOODS_ITEM)=1">
									<xsl:value-of select="//INVOICEGoods/INVOICEGOODS_ITEM[1]/GoodsCode"/>
								</xsl:when>
								<xsl:when  test="$CodGNGUsl3>0">
									<xsl:value-of select="substring($CodGNG,1,2)"/>
								</xsl:when>
							</xsl:choose>
						</xsl:variable>
						<xsl:if test="string-length(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,string-length($GNG))=$GNG]/GrossWeightQuantity)=0"> 
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром, для которого в товаре  Инвойса(ах) не указан вес брутто.'"/>
								<xsl:with-param name="DocId" select="$IdRw"/>
								<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/GNG'"/>							
								<xsl:with-param name="TypeDoc" select="$RwbType"/>
								<xsl:with-param name="PosPkg" select="$RwbPos"/>
							</xsl:call-template>						
						</xsl:if>	
						<xsl:if test="string-length(//INVOICEGoods/INVOICEGOODS_ITEM[substring(GoodsCode,1,string-length($GNG))=$GNG]/TotalCost)=0"> 
							<xsl:call-template name="ErrorNode">
								<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром, для которого в товаре  Инвойса(ах) не указана стоимость.'"/>
								<xsl:with-param name="DocId" select="$IdRw"/>
								<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/GNG'"/>					
								<xsl:with-param name="TypeDoc" select="$RwbType"/>
								<xsl:with-param name="PosPkg" select="$RwbPos"/>
							</xsl:call-template>						
						</xsl:if>
						<xsl:for-each select="RWBGoods/RWBGOODS_ITEM[string-length(PlacesCode)>0]">
							<xsl:variable name="PackN" select="PlacesCode"/>
								<xsl:if test="string-length(document('../../NSI/Ldznsi.xml')//PACKAGE_LDZ_ITEM[CODENSI=$PackN]/CodeLDZ)=0">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с товаром, в котором Код грузового места указан не верно (отсутсвует в справочнике). '"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods/RWBGOODS_ITEM[',position(),']/PlacesCode')"/>	
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>								
							</xsl:if> 
							<xsl:variable name="CodGood" select="GoodsNomenclatureCode"/>
							<xsl:if test="string-length($CodGood)>0 and count(//INVOICEGoods/INVOICEGOODS_ITEM[GoodsCode=$CodGood])=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром, у которого в код товар не найден в инвойсе(ах).'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods/RWBGOODS_ITEM[',position(),']/GoodsNomenclatureCode')"/>					
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="count(RWBGoods/RWBGOODS_ITEM[string-length(GoodsNomenclatureCode)>0 and string-length(../../GNG)=0])>0 or count(RWBGoods/RWBGOODS_ITEM[string-length(GoodsNomenclatureCode)>0 and substring(GoodsNomenclatureCode,1,string-length(../../GNG))=../../GNG])!=count(RWBGoods/RWBGOODS_ITEM[string-length(GoodsNomenclatureCode)>0])">
						<xsl:for-each select="RWBGoods/RWBGOODS_ITEM[string-length(GoodsNomenclatureCode)>0]">
							<xsl:if test="string-length(../../GNG)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненым полем Код ГНГ.'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/GNG'"/>						
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(../../ETSNG)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с не заполненым полем Код ETSNG.'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/GNG'"/>						
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:variable name="CodGNG" select="GoodsNomenclatureCode"/>
							<xsl:if test="count(//INVOICEGoods/INVOICEGOODS_ITEM[GoodsCode=$CodGNG])=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с Кодом товара, по которому невозможно определить товар в Инвойсе(ах).'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods/RWBGOODS_ITEM[',position(),']/GoodsNomenclatureCode')"/>	
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(//INVOICEGoods/INVOICEGOODS_ITEM[GoodsCode=$CodGNG]/GrossWeightQuantity)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром, для которого в товаре  Инвойса(ах) не указан вес брутто.'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/GNG'"/>							
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:if test="string-length(//INVOICEGoods/INVOICEGOODS_ITEM[GoodsCode=$CodGNG]/TotalCost)=0"> 
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит документ СМГС с товаром, для которого в товаре  Инвойса(ах) не указана стоимость.'"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="'RWB/RWB_ITEM/GNG'"/>					
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>						
							</xsl:if>
							<xsl:variable name="PackN" select="PlacesCode"/>
							<xsl:if test="string-length($PackN)>0 and string-length(document('../../NSI/Ldznsi.xml')//PACKAGE_LDZ_ITEM[CODENSI=$PackN]/CodeLDZ)=0">
								<xsl:call-template name="ErrorNode">
									<xsl:with-param name="MessErr" select="'Пакет содержит СМГС с товаром, в котором Код грузового места указан не верно (отсутсвует в справочнике). '"/>
									<xsl:with-param name="DocId" select="$IdRw"/>
									<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/RWBGoods/RWBGOODS_ITEM[',position(),']/PlacesCode')"/>	
									<xsl:with-param name="TypeDoc" select="$RwbType"/>
									<xsl:with-param name="PosPkg" select="$RwbPos"/>
								</xsl:call-template>								
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
				</xsl:choose>	
				<xsl:for-each select="SMGS_CARRIERS/SMGS_CARRIERS_ITEM[string-length(STATIONCODEFROM)>0 and position()>1]">
					<xsl:variable name="FromRw" select="STATIONROADFROM"/>
					<xsl:variable name="FromCr" select="document('../../NSI/TranspNSIXml.xml')//Country_ITEM[RailCode=$FromRw]/ABC2"/>
					<xsl:if test="string-length(../../RWBForwarder/RWBFORWARDER_ITEM[Forwarder_CountryCode=$FromCr]/Forwarder_Name)=0">
						<xsl:call-template name="ErrorNode">
							<xsl:with-param name="MessErr" select="concat('Пакет содержит документ СМГС 2015, в котором в гр. 22 для перевозчика ',NAME,' не указан Экспедитор в соответствующей таблице.')"/>
							<xsl:with-param name="DocId" select="$IdRw"/>
							<xsl:with-param name="PathErr" select="concat('RWB/RWB_ITEM/SMGS_CARRIERS/SMGS_CARRIERS_ITEM[',position()+1,']/NAME')"/>						
							<xsl:with-param name="TypeDoc" select="$RwbType"/>
							<xsl:with-param name="PosPkg" select="$RwbPos"/>
						</xsl:call-template>	
					</xsl:if>			
				</xsl:for-each>
			</xsl:for-each>
		</ResultInformation>
	</xsl:template>
	
</xsl:stylesheet>
